@@ -3,9 +3,9 @@ package Number::ZipCode::JP::Table::Company;
 use strict;
 use warnings;
 
-our $VERSION = '0.20220831';
+our $VERSION = '0.20220930';
 
-# Table last modified: 2022-08-31
+# Table last modified: 2022-09-30
 our %ZIP_TABLE = (
     '001' => '(?:8(?:5(?:[0-2]1|55|77|88)|612))',
     '002' => '(?:850[1-4])',
@@ -103,19 +103,19 @@ our %ZIP_TABLE = (
     '097' => '(?:8(?:5(?:10|85|5[58]|2[57])|6(?:[03]9|[68]6)))',
     '098' => '(?:(?:5(?:[78]92|298|595)|(?:28|62|0[13])92|1(?:69[23]|792)|339[23568]))',
     '099' => '(?:(?:2(?:19[2-8]|49[235]|392)|1(?:49[2568]|19[78]|595)|3(?:29[23]|69[78])|4(?:19[256]|492)|(?:56|65)92|049[245]))',
-    '100' => '(?:(?:8(?:9(?:4[015]|3[0-37]|6[0-2457-9]|8[0-3679]|9[46]|2[0-24679]|1[02-9]|0[1-579]|5[0-35689]|7[013-9])|1(?:7[2468]|1[0137-9]|8[124-9]|2[013-8]|0[1-57-9]|6[05689]|4[0-24]|5[0-24589]|3[0-69])|2(?:28|51|70|0[1357]|8[2358]|3[2-5]|1[4-69]|4[156]|6[0258])|3(?:70|5[015]|2[1245]|3[1-38]|0[2367]|4[15]|1[01]|8[038])|5(?:11|33|4[03]|5[058]|6[07]|8[58]|7[57]|2[0-2]|0[235-7])|6(?:55|2[019]|6[356]|7[67]|1[07]|0[126]|3[129]|4[049])|4(?:02|5[06]|1[015]|3[09]|2[147]|[48][48])|0(?:19|8[06]|5[015]|7[07-9]|6[56])|79[1-4])|6(?:1(?:62|7[0-57]|5[0-2])|2(?:55|77|6[02])|0(?:51|66|80)|75[1-6])|149[28]))',
+    '100' => '(?:(?:8(?:9(?:4[015]|3[0-37]|6[0-2457-9]|8[0-3679]|9[46]|2[0-24679]|1[02-9]|0[1-579]|5[0-35689]|7[013-9])|1(?:7[2468]|1[0137-9]|8[124-9]|2[013-8]|0[1-57-9]|6[05689]|4[0-24]|5[0-24589]|3[0-69])|2(?:28|51|70|0[1357]|8[2358]|3[2-5]|1[4-69]|4[156]|6[0258])|3(?:70|5[015]|2[1245]|3[1-38]|0[2367]|4[15]|1[01]|8[038])|5(?:11|33|4[03]|5[058]|6[07]|8[58]|7[57]|2[0-2]|0[235-7])|6(?:55|2[019]|6[356]|7[67]|1[07]|0[126]|3[129]|4[049])|4(?:02|5[06]|1[015]|3[09]|2[147]|[48][48])|0(?:19|5[015]|7[07-9]|8[068]|6[56])|79[1-4])|6(?:1(?:62|7[0-57]|5[0-2])|2(?:55|77|6[02])|0(?:51|66|80)|75[1-6])|149[28]))',
     '101' => '(?:8(?:5(?:7[5-9]|6[0-2568]|8[0135689]|1[0257-9]|4[2-58]|0[1246-9]|5[24589]|2[0-8]|3[0-5])|4(?:7[05-7]|8[013]|0[57-9]|3[0379]|2[1-579]|5[0-4689]|4[13-9]|6[0-24-9]|1[0-25689])|3(?:6[2356]|0[12578]|7[0-258]|8[1358]|1[013-8]|5[0-689]|4[35-7]|2[13-9]|3[013568])|6(?:4[1-35-8]|8[28]|6[2578]|1[0-25-79]|3[01346-8]|5[14-6]|2[014-9]|7[026]|0[3-79])|9(?:01|50|7[0-37]|4[16]|8[36])|0(?:11|77|5[04]|0[128])|2(?:28|0[124]|1[0359])|7(?:0[137]|1[0-25-8])|1(?:01|89)))',
-    '102' => '(?:8(?:1(?:2[02-58]|8[124-8]|5[0-25]|3[0-289]|0[1-39]|7[0-25-8]|9[0-5]|4[0-24]|6[016]|1[0-257-9])|5(?:0[2-468]|1[0-2569]|8[04-68]|4[013]|5[2-9]|7[01378]|3[0-39]|2[02589]|6[013-79])|6(?:3[0-3579]|4[2-5]|2[0-26-8]|8[0589]|7[17-9]|1[0-47-9]|5[0156]|6[06-8]|0[1-4679])|4(?:7[047]|6[0-24-68]|5[0-259]|0[124-7]|4[0158]|2[0146]|8[489]|3[037]|1[01479])|2(?:5[015]|7[2357]|3[0-24-68]|6[045]|8[28]|2[1-68]|[01][15]|4[016])|3(?:4[19]|3[1-36]|2[124]|1[0134]|8[1-38]|6[24]|7[0237]|5[0367]|0[1-359])|0(?:30|2[24-6]|7[78]|8[0-358]|5[05]|0[58]|1[125689])|7(?:30|9[58])))',
-    '103' => '(?:8(?:4(?:7[0-3]|2[2-7]|0[1-57]|6[0-24-68]|4[38]|8[02478]|3[0-589]|1[0-79]|5[016])|2(?:5[0-2569]|3\d|7[0368]|6[01356]|0[1-68]|8[2457]|1[0-248]|2[124589]|4[013578])|3(?:70|0[1378]|5[0-2458]|8[0348]|4[15-7]|1[1-478]|6[036]|3[01357-9]|2[13-58])|5(?:1[0-257]|5[12468]|7[17]|0[1-36]|2[0-25]|6[67]|8[4-68]|3[4-8]|4[238])|6(?:40|5[0136]|7[67]|6[068]|8[0469]|3[1269])|0[01]1))',
-    '104' => '(?:(?:8(?:1(?:2[2-589]|0[124-689]|6[12578]|1[014-8]|8[1389]|4[25]|7[014-689]|3[0-589]|5[18])|3(?:65|1[023579]|7[07-9]|2[458]|8[013689]|5[0167]|3[02358]|4[0-5]|0[12467])|5(?:72|1[028]|3[035689]|8[01458]|2[136-8]|5[014-689]|6[068]|4[35-8]|0[1256])|4(?:70|3[013589]|5[056]|1[3569]|0[124-8]|8[168]|2[0-469]|6[08]|4[02-49])|2(?:38|40|71|6[26]|5[0-24578]|1[0-258]|0[568]|8[0-59])|6(?:14|5[06]|8[05]|7[08]|6[15])|0(?:55|77|0[1-47]|1[01]))|6241))',
-    '105' => '(?:(?:8(?:4(?:8[2-6]|5[1-36-8]|3[13-7]|6[014-689]|7[0-357]|0[1-3578]|4[014-9]|2[0347-9]|1[0-24-9])|5(?:6[03578]|1[0-2568]|5[013-8]|8[0-57-9]|7[4-9]|0[1-3578]|2[1-57-9]|3[0457]|4[03-6])|6(?:7[026-8]|3[04]|6[0568]|8[015689]|2[0135-7]|5[468]|1[013-57]|4[024]|0[3468])|3(?:3[01358]|0[1-8]|2[0235]|1[0-589])|0(?:[12]0|39|55|0[1258]|7[07]|8[58])|7(?:88|0[127]|1[1267]))|7(?:0(?:50|77)|444)|6[09]50))',
+    '102' => '(?:8(?:1(?:2[02-58]|8[124-8]|5[0-25]|3[0-289]|0[1-39]|7[0-25-8]|9[0-5]|4[0-24]|6[016]|1[0-257-9])|5(?:0[2-468]|1[0-2569]|8[04-68]|4[013]|5[2-9]|7[01378]|3[0-39]|2[02589]|6[013-79])|6(?:3[0-3579]|4[2-5]|2[0-26-8]|8[0589]|7[17-9]|1[0-47-9]|5[0156]|6[06-8]|0[1-4679])|4(?:7[047]|6[0-24-68]|5[0-259]|0[124-7]|4[0158]|2[0146]|8[489]|3[037]|1[01479])|2(?:5[015]|7[2357]|3[0-24-68]|6[045]|8[28]|2[1-68]|[01][15]|4[016])|3(?:4[19]|7[0-37]|3[1-36]|2[124]|1[0134]|8[1-38]|6[24]|5[0367]|0[1-359])|0(?:30|2[24-6]|7[78]|8[0-358]|5[05]|0[58]|1[125689])|7(?:30|9[58])))',
+    '103' => '(?:8(?:4(?:7[0-3]|2[2-7]|0[1-57]|6[0-24-68]|4[38]|8[02478]|3[0-589]|1[0-79]|5[016])|2(?:5[0-2569]|3\d|7[0368]|6[01356]|0[1-68]|8[2457]|1[0-248]|2[124589]|4[013578])|3(?:70|0[1378]|8[0348]|4[15-7]|1[1-478]|5[0-248]|6[036]|3[01357-9]|2[13-58])|5(?:1[0-257]|5[12468]|7[17]|0[1-36]|2[0-25]|6[67]|8[4-68]|3[4-8]|4[238])|6(?:40|5[0136]|7[67]|6[068]|8[0469]|3[1269])|0[01]1))',
+    '104' => '(?:(?:8(?:1(?:2[2-589]|6[12578]|1[014-8]|8[1389]|4[25]|7[014-689]|3[0-589]|5[18]|0[124589])|3(?:65|1[023579]|7[07-9]|2[458]|8[013689]|5[0167]|3[02358]|4[0-5]|0[12467])|5(?:72|1[028]|3[035689]|8[01458]|2[136-8]|5[014-689]|6[068]|4[35-8]|0[1256])|4(?:70|3[013589]|5[056]|1[3569]|0[124-8]|8[168]|2[0-469]|6[08]|4[02-49])|2(?:38|40|71|6[26]|5[0-24578]|1[0-258]|0[568]|8[0-59])|6(?:14|5[06]|8[05]|7[08]|6[15])|0(?:55|77|0[1-47]|1[01]))|6241))',
+    '105' => '(?:(?:8(?:4(?:8[2-6]|5[1-36-8]|3[13-7]|6[014-689]|7[0-357]|0[1-3578]|4[014-9]|2[0347-9]|1[0-24-9])|5(?:6[03578]|1[0-2568]|0[1-357-9]|5[013-8]|8[0-57-9]|7[4-9]|2[1-57-9]|3[0457]|4[03-6])|6(?:7[026-8]|3[04]|6[0568]|8[015689]|2[0135-7]|5[468]|1[013-57]|4[0-24]|0[3468])|3(?:3[01358]|0[1-8]|2[0235]|1[0-589])|0(?:[12]0|39|55|0[1258]|7[07]|8[58])|7(?:88|0[127]|1[1267]))|7(?:0(?:[58]0|77)|444)|6[09]50))',
     '106' => '(?:(?:8(?:5(?:6[0-35-79]|0[78]|7[136-8]|3[17]|1[458]|2[12]|5[0-25689]|4[145]|8[0157-9])|6(?:77|4[0-2489]|5[25]|1[168]|6[58]|3[0569]|0[18]|2[0256])|0(?:11|39|0[17])|(?:10|79)7|4(?:01|87))|6(?:1(?:61|88)|06[06])))',
-    '107' => '(?:8(?:4(?:20|34|5[06]|0[1-4]|7[17]|8[24]|6[036-8]|1[0-246-9]|4[08])|6(?:50|8[06]|0[14]|1[5-79]|7[46]|3[0-3689]|2[0357]|6[68])|5(?:[37]2|81|1[14]|0[2578]|2[0178]|6[037]|5[0268]|4[56])|3(?:60|4[0289]|7[013]|2[0346]|8[048]|3[026]|5[125])|0(?:[16]0|77|0[16])|797))',
+    '107' => '(?:8(?:4(?:20|34|5[06]|0[1-4]|7[17]|8[24]|6[036-8]|1[0-246-9]|4[08])|5(?:[37]2|81|1[14]|0[2578]|2[0178]|6[037]|5[0268]|4[56])|6(?:01|50|8[06]|1[5-79]|7[46]|3[0-3689]|2[0357]|6[68])|3(?:60|4[0289]|7[013]|2[0346]|8[048]|3[026]|5[125])|0(?:[16]0|77|0[16])|797))',
     '108' => '(?:(?:8(?:5(?:2[0-35]|4[0358]|3[02369]|6[0468]|7[0135]|5[0-35-8]|1[0-2]|0[1-46-9]|8[0-3568])|3(?:2[25689]|7[2359]|8[013-689]|3[0348]|5[058]|6[01]|4[15]|1[035]|0[13578])|2(?:8[028]|2[0-245]|7[056]|4[0-38]|1[0-25-7]|0[1-36-9]|3[0-4]|5[05])|4(?:56|0[3-57]|2[013-5]|7[078]|1[014-7]|3[29]|6[68]|4[48])|6(?:50|0[1267]|1[0-25-7]|2[28]|3[1-3689]|4[0-28])|0(?:[258]0|[17]1|0[15])|7(?:07|1[03])|11[78])|63(?:50|63)))',
     '109' => '(?:8792)',
-    '110' => '(?:8(?:5(?:6[0-25-7]|4[01368]|5[0589]|7[5-8]|3[0-4679]|0[1-3579]|1[0135-7]|8[02-468]|2[024])|6(?:53|2[0-2568]|6[0259]|4[1245]|3[0158]|0[259]|8[015-7]|1[04589]|7[35-8])|7(?:8[027]|1[2-6]|2[235]|3[36]|0[68])|408|807))',
+    '110' => '(?:8(?:5(?:6[0-25-7]|4[01368]|7[5-8]|3[0-4679]|0[1-3579]|1[0135-7]|5[059]|8[02-468]|2[024])|6(?:53|2[0-2568]|6[0259]|4[1245]|3[0158]|0[259]|8[015-7]|1[04589]|7[35-8])|7(?:8[027]|1[2-6]|2[235]|3[36]|0[68])|408|807))',
     '111' => '(?:8(?:5(?:43|1[0-258]|8[058]|5[1568]|7[57]|6[0167]|2[125]|0[125-8]|3[0-59])|6(?:4[028]|3[01379]|[12][0-258]|7[6-8]|8[1368]|0[2568]|6[16]|5[05])|7(?:[56]5|21|98|0[178]|1[01])|081))',
-    '112' => '(?:8(?:6(?:90|6[02-48]|4[245]|0[1467]|2[02579]|1[0-289]|7[01578]|5[0-57]|8[0-578]|3[02-5])|5(?:7[0356]|4[018]|6[02369]|1[1246]|3[0138]|0[1-35689]|5[015-8]|2[48]|8[035])|7(?:[156]0|78|0[12])|0(?:[01]1|88)|138))',
+    '112' => '(?:8(?:6(?:90|6[02-48]|4[245]|0[1467]|2[02579]|1[0-289]|7[01578]|5[0-57]|8[0-578]|3[02-5])|5(?:7[0356]|4[018]|6[02369]|2[458]|1[1246]|3[0138]|0[1-35689]|5[015-8]|8[035])|7(?:[156]0|78|0[12])|0(?:[01]1|88)|138))',
     '113' => '(?:8(?:4(?:4[148]|7[1479]|8[3-58]|2[0-3]|1[0-358]|6[2-6]|3[13-5]|5[0169]|0[1248])|5(?:70|0[13-579]|3[04-68]|6[0-46]|4[1369]|1[02379]|2[0145]|5[1356])|6(?:77|3[38]|5[04-8]|8[16]|1[0-2]|0[1-48]|6[0-378])|7(?:01|1[0-29])|139|311))',
     '114' => '(?:8(?:5(?:95|0[1-35-8]|8[013-58]|6[0-25]|2[0-468]|7[147]|4[01356]|5[02-57]|3[0-24589]|1[02457-9])|6(?:11|86|0[2-6])))',
     '115' => '(?:8(?:5(?:55|8[568]|1[01]|2[49])|(?:00|71)1|6(?:22|50)))',
@@ -124,13 +124,13 @@ our %ZIP_TABLE = (
     '121' => '(?:8(?:5(?:77|1[025]|0[458]|8[58]|5[05]|2[01])|6(?:82|3[39]|1[01])|7(?:11|29)|080))',
     '123' => '(?:85(?:[58]8|40|1[1247]|0[135-9]))',
     '124' => '(?:85(?:60|77|2[04]|3[03589]|0[1-39]|8[58]|5[05]|1[01]))',
-    '125' => '(?:8(?:5(?:1[1-57]|0[3-8]|8[58]|2[026])|601))',
+    '125' => '(?:8(?:5(?:0[3-8]|8[58]|1[1-47]|2[026])|601))',
     '130' => '(?:8(?:5(?:8[03-58]|2[0-258]|7[057]|3[013-589]|5[3-8]|4[3568]|6[135-7]|0[13-9]|1[0-8])|6(?:25|86|7[17]|3[67]|5[05]|6[068]|1[125]|0[1-689]|4[024])|7(?:[12]0|0[16])))',
     '131' => '(?:8(?:5(?:65|1[0-389]|3[03]|2[0467]|8[458]|5[05]|0[1357-9])|139|634|711))',
     '132' => '(?:8(?:5(?:[18]5|33|5[015]|0[137]|6[27])|6(?:01|74|[68][68])|7(?:11|3[029])))',
     '133' => '(?:8(?:5(?:[01]1|8[05]|5[238])|70[46]))',
     '134' => '(?:8(?:5(?:[15]5|20|33|7[05-7]|8[5-8]|0[237])|6(?:22|86|[14][02]|0[1-39]|3[01])|702))',
-    '135' => '(?:8(?:5(?:48|7[057-9]|5\d|3[0-358]|2[1-3578]|8[1257]|1[0-478]|0[12458]|6[035-8])|4(?:4[0358]|2[27]|0[24]|5[18]|8[0-2]|7[037]|6[014]|1[15]|3[026])|6(?:86|0[28]|2[0-25]|6[168]|3[0-29]|7[078]|1[014-9]|5[059])|3(?:[25]0|8[3-57]|0[136]|7[05]|6[023]|3[01]|1[0-28])|1(?:21|45|50|1[0-58]|0[89]|3[0479]|8[01])|7(?:3[0-3]|2[0-37]|0[17]|1[0178])|2(?:10|2[24])|0(?:74|80)))',
+    '135' => '(?:8(?:5(?:48|7[057-9]|5\d|3[0-358]|2[1-3578]|8[1257]|1[0-478]|0[12458]|6[035-8])|4(?:4[0358]|2[27]|0[24]|5[18]|8[0-2]|7[037]|6[014]|1[15]|3[026])|6(?:86|0[28]|2[0-25]|6[168]|3[0-29]|7[078]|1[014-9]|5[059])|3(?:[25]0|8[3-57]|0[136]|7[05]|6[023]|3[01]|1[0-28])|1(?:21|45|50|1[01458]|0[89]|3[0479]|8[01])|7(?:3[0-3]|2[0-37]|0[17]|1[0178])|2(?:10|2[24])|0(?:74|80)))',
     '136' => '(?:8(?:5(?:3[135]|4[03]|5[056]|8[01589]|1[2357]|7[057]|6[07]|0[1257]|2[1-35])|6(?:51|8[06]|1[25]|[37][0157]|2[0267]|6[68]|4[08]|0[3578])|7(?:[23]3|11)|88[08]|405|908))',
     '137' => '(?:8(?:6(?:23|86)|08[18]|581))',
     '140' => '(?:8(?:5(?:90|4[0137-9]|3[0136-9]|8[0346]|7[1-36]|6[0367]|2[1-3569]|0[235-9]|5[1248]|1[1256])|6(?:4[04]|3[0147]|6[013689]|2[13568]|7[025-8]|5[03-68]|0[12]|8[0278]|1[14-79])|7(?:88|1[015-7]|2[12]|0[279])|810))',
@@ -140,8 +140,8 @@ our %ZIP_TABLE = (
     '144' => '(?:8(?:5(?:44|66|5[015]|8[018]|7[057]|2[25]|3[1-356]|1[01356]|0[56])|6(?:02|11|5[056]|7[78]|2[1-36]|6[016])))',
     '145' => '(?:85(?:[23]3|58|66|0[16]|1[15]))',
     '146' => '(?:8(?:5(?:22|31|67|0[135]|5[158]|8[058]|1[0-25]|7[67]|4[034])|6(?:[03]1|10|77|2[03]|5[056]|6[68])))',
-    '150' => '(?:8(?:5(?:45|6[37]|2[256]|0[1-357-9]|7[57]|8[578]|1[0-24-7]|5[1-5]|3[038])|3(?:19|4[03]|7[37]|3[0368]|8[45]|0[167]|2[24-8]|5[05]|6[036])|4(?:12|36|55|0[289]|8[28]|4[08])|9(?:02|11|40|55|67|2[35]|3[258])|0(?:[08]1|1[059])|6(?:88|7[237])))',
-    '151' => '(?:8(?:5(?:3\d|0[2-79]|5[024589]|1[016-9]|6[1-35-9]|[24][0-57-9]|9[0-2]|7[0-46-8]|8[02-7])|6(?:5[1-3]|7[1-7]|0[01])|40[14]|070))',
+    '150' => '(?:8(?:5(?:45|6[37]|2[256]|0[1-357-9]|7[57]|8[578]|1[0-24-7]|5[1-5]|3[038])|3(?:19|4[03]|7[37]|3[0368]|0[17]|8[45]|2[24-8]|5[05]|6[036])|4(?:12|36|55|0[289]|8[28]|4[08])|9(?:02|11|40|55|67|2[35]|3[258])|0(?:[08]1|1[059])|6(?:88|7[237])))',
+    '151' => '(?:8(?:5(?:[34]\d|0[2-79]|5[024589]|1[016-9]|6[1-35-9]|2[0-57-9]|9[0-2]|7[0-46-8]|8[02-7])|6(?:5[1-3]|7[1-7]|0[01])|40[14]|070))',
     '152' => '(?:8(?:5(?:61|4[149]|2[0-257]|0[36-8]|7[08]|1[01]|5[0-28]|3[1-35])|9(?:1[03]|0[24579])|6[02]1))',
     '153' => '(?:8(?:5(?:7[1378]|2[0-356]|6[057]|5[0-68]|4[0135]|8[0-25-79]|0[1-68]|3[0169]|1[02568])|6(?:01|40|1[06]|8[78]|2[02]|6[025689]|5[02-57]|3[013568]|7[017])|9(?:1[134]|0[246]|2[357]|3[034679])))',
     '154' => '(?:8(?:5(?:8[0-245]|4[3-5]|3[02369]|6[05-8]|2[0135]|0[3-69]|5[1-5]|1[0156]|7[017])|7(?:03|32)))',
@@ -169,7 +169,7 @@ our %ZIP_TABLE = (
     '178' => '(?:8(?:5(?:11|67|0[12])|6(?:[68]6|01|24)))',
     '179' => '(?:8(?:9(?:0[134679]|1[14])|501))',
     '180' => '(?:8(?:5(?:66|80|1[79]|2[027]|7[17]|3[138]|0[58])|6(?:29|33|1[018]|0[28])|7(?:50|77)))',
-    '181' => '(?:8(?:5(?:41|67|3[135]|7[17]|8[568]|0[35]|1[0178]|5[15]|2[0-28])|6(?:22|33|48|1[124]|0[18])|001))',
+    '181' => '(?:8(?:5(?:41|67|3[135]|7[17]|8[568]|2[128]|0[35]|1[0178]|5[15])|6(?:22|33|48|1[124]|0[18])|001))',
     '182' => '(?:8(?:5(?:08|67|70|85|2[025]|5[58]|1[0-2])|6(?:21|86|0[12])|00[16]))',
     '183' => '(?:8(?:5(?:61|70|85|1[1-469]|2[124-689]|5[013]|3[02469]|4[0189]|0[1256])|70[1-35-7]))',
     '184' => '(?:8(?:5(?:[34]3|22|95|1[015]|5[58]|7[57]|0[1-58]|8[1458])|795))',
@@ -223,7 +223,7 @@ our %ZIP_TABLE = (
     '241' => '(?:8(?:5(?:25|1[25]|0[12])|606))',
     '242' => '(?:8(?:5(?:[58]5|77|0[27])|6(?:01|10)))',
     '243' => '(?:(?:8(?:5(?:88|5[015]|3[13]|7[17]|2[12]|1[01]|0[15])|6(?:89|0[14]))|0(?:4(?:60|[89][2-7])|2(?:81|9[278])|19[23578]|392)))',
-    '244' => '(?:8(?:5(?:0[1-3]|7[17]|2[28]|5[058]|8[589]|6[679]|1[01]|3[039])|601))',
+    '244' => '(?:8(?:5(?:0[1-3]|7[17]|2[28]|5[058]|8[589]|6[679]|1[01]|3[039])|60[12]))',
     '245' => '(?:8(?:5(?:[16]0|42|89|5[058]|7[57])|65[01]))',
     '246' => '(?:85(?:20|5[06]))',
     '247' => '(?:8(?:5(?:[156]0|8[58]|7[078]|3[038])|6(?:[13]0|86)|730))',
@@ -231,7 +231,7 @@ our %ZIP_TABLE = (
     '249' => '(?:8(?:510|686))',
     '250' => '(?:(?:0(?:2(?:80|9[2-68])|19[23]|39[28]|493|592)|85(?:11|55|60|88)))',
     '251' => '(?:8(?:5(?:22|70|4[03]|8[018]|5[0158]|3[0134]|1[0135]|6[067]|0[125])|601))',
-    '252' => '(?:(?:5(?:2(?:01|33|77|9[3-578]|8[0568]|6[09]|1[0-5]|2[125]|5[0258])|1(?:[56]2|8[13589]|7[27]|9[12]))|0(?:3(?:7[013-578]|9[258]|8[013568])|88[0-3568])|85(?:[02]2|11|40|85|3[89]|7[02]|6[067]|5[08])|119[235]))',
+    '252' => '(?:(?:5(?:2(?:01|33|77|9[3-578]|8[0568]|2[0-25]|6[09]|1[0-5]|5[0258])|1(?:[56]2|8[13589]|7[27]|9[12]))|0(?:3(?:7[013-578]|9[258]|8[013568])|88[0-3568])|85(?:[02]2|11|40|85|3[89]|7[02]|6[067]|5[08])|119[235]))',
     '253' => '(?:(?:8(?:5(?:10|22|43|7[17]|8[58]|5[05]|3[01])|6(?:60|86))|019[356]))',
     '254' => '(?:8(?:5(?:10|43|55|78|0[1-3]|6[27]|3[023]|8[589])|6(?:01|86|1[024])))',
     '255' => '(?:8555)',
@@ -294,7 +294,7 @@ our %ZIP_TABLE = (
     '318' => '(?:85[01]1)',
     '319' => '(?:(?:1(?:1(?:8[248]|9[24-7])|29[235]|59[23]|393)|0(?:39[3-57]|29[245]|19[28])|2[16]92|3595))',
     '320' => '(?:8(?:5(?:5[015]|3[0-38]|0[1-35-8]|8[058]|4[013]|7[07]|6[046]|2[1-358]|1[0-2457])|6(?:01|20|55|68|1[018]|8[068])))',
-    '321' => '(?:(?:3(?:29[235-8]|39[2358]|49[378]|59[578])|0(?:29[2358]|19[458]|59[235]|692)|2(?:59[23568]|49[23]|792)|4(?:39[23568]|29[235])|1(?:29[23]|49[23])|85(?:[58]5|0[25])))',
+    '321' => '(?:(?:3(?:29[235-8]|39[2358]|49[378]|59[578])|0(?:29[2358]|19[458]|59[235]|692)|2(?:59[23568]|49[23]|792)|4(?:39[23568]|29[235])|1(?:29[238]|49[23])|85(?:[58]5|0[25])))',
     '322' => '(?:(?:8(?:5(?:11|0[1-3]|8[58]|5[05])|6(?:66|88|0[13]))|0(?:393|692)))',
     '323' => '(?:(?:8(?:5(?:11|58|67|8[56])|6(?:[01]1|78|86)|75[56])|019[24]|1192))',
     '324' => '(?:(?:8(?:5(?:[24]0|01|85|1[06]|5[015])|6(?:25|86|4[12]))|0(?:59[2-6]|29[23]|69[23]|492)))',
@@ -407,8 +407,8 @@ our %ZIP_TABLE = (
     '433' => '(?:8(?:5(?:[01]1|67|5[058])|601))',
     '434' => '(?:8(?:5(?:11|33|50|0[125])|601))',
     '435' => '(?:8(?:5(?:40|75|3[39]|0[25]|2[02]|6[0178]|8[58]|1[05]|5[1578])|6(?:42|86|1[19]|6[01])))',
-    '436' => '(?:8(?:5(?:55|0[1-3])|65[0-3]))',
-    '437' => '(?:(?:1(?:6(?:9[2-8]|8[68])|19[2-7]|39[2357]|49[24-6]|59[2-4]|292)|8(?:5(?:[45]5|11|0[12])|6(?:[01]1|[68]6))|0(?:29[23]|69[23])))',
+    '436' => '(?:8(?:5(?:55|0[1-3])|65[0-3]|701))',
+    '437' => '(?:(?:1(?:6(?:9[2-8]|8[68])|19[2-7]|49[2-6]|39[2357]|59[2-4]|292)|8(?:5(?:[45]5|11|0[12])|6(?:[01]1|[68]6))|0(?:29[23]|69[23])))',
     '438' => '(?:(?:8(?:5(?:01|10|43|77|85|5[058])|6(?:[01]1|22|50|86)|71[18])|0(?:19[235]|292)))',
     '439' => '(?:865[01])',
     '440' => '(?:8(?:5(?:43|0[124-8]|3[013]|[12][0-8])|60[134]))',
@@ -512,7 +512,7 @@ our %ZIP_TABLE = (
     '540' => '(?:(?:8(?:5(?:6[06]|5[0-3589]|4[0147]|2[1267]|8[15-7]|3[03-5]|0[1578]|7[01578]|1[0-2579])|6(?:86|1[015]|4[25]|2[02]|3[09]|0[2-8]|7[078]|6[08])|795)|6255))',
     '541' => '(?:(?:8(?:5(?:5[0136-9]|2[013-689]|1[135-8]|4[0-35-7]|7[2568]|8[1579]|0[1-35689]|6[0136-8]|3[014578])|765)|6666))',
     '542' => '(?:8(?:5(?:33|42|77|0[1-4]|8[0568]|6[67]|2[235]|5[0458]|1[01])|6(?:54|60|8[68])|745))',
-    '543' => '(?:8(?:5(?:[34]3|11|0[1-3]|[58][58])|6(?:01|66|8[68])|921))',
+    '543' => '(?:8(?:5(?:[34]3|11|0[1-3]|[58][58])|6(?:01|66|8[68])))',
     '544' => '(?:8(?:5(?:[58]5|01)|6[68]6))',
     '545' => '(?:85(?:[01]1|22|33|45|5[05]|8[56]))',
     '546' => '(?:8501)',
@@ -538,7 +538,7 @@ our %ZIP_TABLE = (
     '567' => '(?:8(?:5(?:[34]0|57|1[015]|2[0135]|8[58]|6[57]|7[08]|0[1257])|6(?:51|80)))',
     '569' => '(?:(?:8(?:5(?:33|49|0[135]|5[158]|2[02]|8[58]|7[0157]|6[679]|1[0-2])|6(?:60|86))|1(?:19[2-7]|09[24-68])))',
     '570' => '(?:8(?:5(?:39|40|0[167]|[58][58]|1[15])|6(?:34|66)|787))',
-    '571' => '(?:8(?:5(?:[45]5|33|67|71|8[05]|0[2-47])|6(?:33|40|86)))',
+    '571' => '(?:8(?:5(?:[45]5|33|67|71|8[05]|0[2-47])|6(?:[24]0|33|86)))',
     '572' => '(?:85(?:40|8[01589]|0[158]|2[28]|3[013]|7[02]|5[0158]|6[67]|1[01]))',
     '573' => '(?:(?:8(?:5(?:34|56|67|73|88|0[58]|1[01])|666)|10(?:[34]0|1[03]|0[1478])|019[356]))',
     '574' => '(?:85(?:[58]5|01|3[0-4]))',
@@ -636,7 +636,7 @@ our %ZIP_TABLE = (
     '670' => '(?:8(?:5(?:3[03]|2[04]|4[34]|7[057]|8[058]|0[1-356]|6[067]|5[0458]|1[017])|6(?:5[25]|6[068]|7[57]|8[029])))',
     '671' => '(?:(?:1(?:2(?:9[235]|8[0-35689])|6(?:92|8[0-248])|1(?:92|8[018])|59[235]|39[23])|2(?:19[238]|59[358]|28[08])|419[23]|0295))',
     '672' => '(?:8(?:5(?:01|67|5[058]|8[58])|6(?:55|66|77)))',
-    '673' => '(?:(?:8(?:5(?:[01]1|85)|6(?:66|8[68]))|1(?:49[3-5]|192|395)|0[45]92))',
+    '673' => '(?:(?:8(?:5(?:[01]1|22|85)|6(?:66|8[68]))|1(?:49[3-5]|192|395)|0[45]92))',
     '674' => '(?:8(?:5(?:01|85)|686))',
     '675' => '(?:(?:8(?:5(?:22|33|66|77|88|1[019]|5[58]|0[15])|6(?:11|8[68]))|01(?:9[2-468]|8[0-68])|1(?:3(?:80|9[25])|192|297)|239[35]))',
     '676' => '(?:8(?:5(?:01|33|40|58|66|85|1[03])|6(?:55|7[07]|8[68])))',
@@ -769,7 +769,7 @@ our %ZIP_TABLE = (
     '808' => '(?:(?:8(?:5(?:1[045]|5[058]|8[58]|0[125])|606)|0196))',
     '809' => '(?:8501)',
     '810' => '(?:8(?:5(?:3[0-357-9]|1[1-9]|5[135-8]|7[01578]|2[0-578]|0[1-46-9]|8[13-57-9]|4[013-6]|6[0135-8])|6(?:8[035689]|4[28]|6[02-79]|7[03-7]|1[0179]|0[13-9]|2[0-2579]|5[0-6]|3[1346-9])|7(?:98|2[0-257]|3[14]|0[157]|1[06-8])))',
-    '811' => '(?:(?:2(?:29[2-578]|19[2-6]|39[258]|49[256]|592)|3(?:19[23578]|29[3568]|492|598)|4(?:19[2358]|39[23]|292)|0(?:19[2-7]|295)|1(?:39[2-6]|292)|5192))',
+    '811' => '(?:(?:2(?:29[2-578]|19[2-6]|39[2358]|49[256]|592)|3(?:19[23578]|29[3568]|492|598)|4(?:19[2358]|39[23]|292)|0(?:19[2-7]|295)|1(?:39[2-6]|292)|5192))',
     '812' => '(?:(?:8(?:6(?:8[0134679]|3\d|0[1-9]|7[025-8]|5[0-79]|[14][0-8]|2[0-24-9]|6[0-25689])|5(?:[1-3578]\d|0[1-9]|6[0-689]|4[0-8])|7(?:35|0[5-9]|1[78]|9[24]))|95(?:[24]0|11|8[89]|0[235]|5[12])))',
     '813' => '(?:8(?:5(?:29|33|55|68|1[39]|7[78]|0[13]|8[58])|6(?:09|2[36]|8[01])))',
     '814' => '(?:(?:8(?:5(?:65|77|0[135]|8[58]|1[0-2]|2[0245]|5[03-6])|6(?:02|51)|798)|01(?:80|9[238])))',
@@ -886,7 +886,7 @@ our %ZIP_TABLE = (
     '927' => '(?:(?:0(?:49[235]|29[23]|695)|129[57]|219[23]|8601))',
     '928' => '(?:(?:8(?:5(?:[28]5|41|0[12])|609)|039[235]))',
     '929' => '(?:(?:1(?:2(?:87|9[23])|39[2-7]|19[23568]|49[2-4]|[6-8]92)|0(?:49[2-5]|19[238]|29[26]|39[23])|2(?:19[25]|[23]92)))',
-    '930' => '(?:(?:8(?:5(?:2[0-25-7]|4[03-58]|6[0-35-7]|3[0-35-9]|0[124-9]|8[0135-9]|1[0-35-8]|7[013578]|5[024-68])|6(?:5[06]|0[3-5]|4[24]|3[067]|8[0167]|1[01]|6[06-8]))|0(?:19[3-68]|39[3-57]|29[238])|1(?:29[258]|392)|2198))',
+    '930' => '(?:(?:8(?:5(?:2[0-25-7]|4[03-58]|0[14-9]|6[0-35-7]|3[0-35-9]|8[0135-9]|1[0-35-8]|7[013578]|5[024-68])|6(?:5[06]|0[3-5]|4[24]|3[067]|8[0167]|1[01]|6[06-8]))|0(?:19[3-68]|39[3-57]|29[238])|1(?:29[258]|392)|2198))',
     '931' => '(?:8(?:5(?:33|62|2[23]|4[03]|7[17]|0[128]|[58][58]|1[0157])|6(?:01|88)))',
     '932' => '(?:(?:8(?:5(?:40|67|75|1[0-258]|3[38]|5[0158]|8[58]|0[1-358]|2[0258])|611)|0(?:39[23568]|29[238]|19[38])))',
     '933' => '(?:(?:8(?:5(?:4[03]|6[367]|8[58]|1[01568]|0[126-8]|3[0-3578]|5[08]|2[035-8])|6(?:[28]8|66|1[01]|0[1356])|7(?:77|88))|0(?:39[235-8]|19[235]|29[35])))',
